# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: hfc/protos/token/prover.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from hfc.protos.token import expectations_pb2 as hfc_dot_protos_dot_token_dot_expectations__pb2
from hfc.protos.token import transaction_pb2 as hfc_dot_protos_dot_token_dot_transaction__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='hfc/protos/token/prover.proto',
  package='token',
  syntax='proto3',
  serialized_options=_b('\n#org.hyperledger.fabric.protos.tokenZ*github.com/hyperledger/fabric/protos/token'),
  serialized_pb=_b('\n\x1dhfc/protos/token/prover.proto\x12\x05token\x1a\x1fgoogle/protobuf/timestamp.proto\x1a#hfc/protos/token/expectations.proto\x1a\"hfc/protos/token/transaction.proto\"A\n\x0cTokenToIssue\x12\x11\n\trecipient\x18\x01 \x01(\x0c\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x10\n\x08quantity\x18\x03 \x01(\x04\"=\n\x16RecipientTransferShare\x12\x11\n\trecipient\x18\x01 \x01(\x0c\x12\x10\n\x08quantity\x18\x02 \x01(\x04\"I\n\x0bTokenOutput\x12\x1a\n\x02id\x18\x01 \x01(\x0b\x32\x0e.token.InputId\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x10\n\x08quantity\x18\x03 \x01(\x04\"3\n\rUnspentTokens\x12\"\n\x06tokens\x18\x01 \x03(\x0b\x32\x12.token.TokenOutput\"!\n\x0bListRequest\x12\x12\n\ncredential\x18\x01 \x01(\x0c\"Q\n\rImportRequest\x12\x12\n\ncredential\x18\x01 \x01(\x0c\x12,\n\x0ftokens_to_issue\x18\x02 \x03(\x0b\x32\x13.token.TokenToIssue\"w\n\x0fTransferRequest\x12\x12\n\ncredential\x18\x01 \x01(\x0c\x12!\n\ttoken_ids\x18\x02 \x03(\x0b\x32\x0e.token.InputId\x12-\n\x06shares\x18\x03 \x03(\x0b\x32\x1d.token.RecipientTransferShare\"b\n\rRedeemRequest\x12\x12\n\ncredential\x18\x01 \x01(\x0c\x12!\n\ttoken_ids\x18\x02 \x03(\x0b\x32\x0e.token.InputId\x12\x1a\n\x12quantity_to_redeem\x18\x03 \x01(\x04\">\n\x17\x41llowanceRecipientShare\x12\x11\n\trecipient\x18\x01 \x01(\x0c\x12\x10\n\x08quantity\x18\x02 \x01(\x04\"\x81\x01\n\x0e\x41pproveRequest\x12\x12\n\ncredential\x18\x01 \x01(\x0c\x12\x38\n\x10\x61llowance_shares\x18\x02 \x03(\x0b\x32\x1e.token.AllowanceRecipientShare\x12!\n\ttoken_ids\x18\x03 \x03(\x0b\x32\x0e.token.InputId\"y\n\x12\x45xpectationRequest\x12\x12\n\ncredential\x18\x01 \x01(\x0c\x12,\n\x0b\x65xpectation\x18\x02 \x01(\x0b\x32\x17.token.TokenExpectation\x12!\n\ttoken_ids\x18\x03 \x03(\x0b\x32\x0e.token.InputId\"\x82\x01\n\x06Header\x12-\n\ttimestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\nchannel_id\x18\x02 \x01(\t\x12\r\n\x05nonce\x18\x03 \x01(\x0c\x12\x0f\n\x07\x63reator\x18\x04 \x01(\x0c\x12\x15\n\rtls_cert_hash\x18\x05 \x01(\x0c\"\x98\x03\n\x07\x43ommand\x12\x1d\n\x06header\x18\x01 \x01(\x0b\x32\r.token.Header\x12.\n\x0eimport_request\x18\x02 \x01(\x0b\x32\x14.token.ImportRequestH\x00\x12\x32\n\x10transfer_request\x18\x03 \x01(\x0b\x32\x16.token.TransferRequestH\x00\x12*\n\x0clist_request\x18\x04 \x01(\x0b\x32\x12.token.ListRequestH\x00\x12.\n\x0eredeem_request\x18\x05 \x01(\x0b\x32\x14.token.RedeemRequestH\x00\x12\x30\n\x0f\x61pprove_request\x18\x06 \x01(\x0b\x32\x15.token.ApproveRequestH\x00\x12\x37\n\x15transfer_from_request\x18\x07 \x01(\x0b\x32\x16.token.TransferRequestH\x00\x12\x38\n\x13\x65xpectation_request\x18\x08 \x01(\x0b\x32\x19.token.ExpectationRequestH\x00\x42\t\n\x07payload\"3\n\rSignedCommand\x12\x0f\n\x07\x63ommand\x18\x01 \x01(\x0c\x12\x11\n\tsignature\x18\x02 \x01(\x0c\"m\n\x15\x43ommandResponseHeader\x12-\n\ttimestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x14\n\x0c\x63ommand_hash\x18\x02 \x01(\x0c\x12\x0f\n\x07\x63reator\x18\x03 \x01(\x0c\")\n\x05\x45rror\x12\x0f\n\x07message\x18\x01 \x01(\t\x12\x0f\n\x07payload\x18\x02 \x01(\x0c\"\xcd\x01\n\x0f\x43ommandResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.token.CommandResponseHeader\x12\x1b\n\x03\x65rr\x18\x02 \x01(\x0b\x32\x0c.token.ErrorH\x00\x12\x34\n\x11token_transaction\x18\x03 \x01(\x0b\x32\x17.token.TokenTransactionH\x00\x12.\n\x0eunspent_tokens\x18\x04 \x01(\x0b\x32\x14.token.UnspentTokensH\x00\x42\t\n\x07payload\"<\n\x15SignedCommandResponse\x12\x10\n\x08response\x18\x01 \x01(\x0c\x12\x11\n\tsignature\x18\x02 \x01(\x0c\x32P\n\x06Prover\x12\x46\n\x0eProcessCommand\x12\x14.token.SignedCommand\x1a\x1c.token.SignedCommandResponse\"\x00\x42Q\n#org.hyperledger.fabric.protos.tokenZ*github.com/hyperledger/fabric/protos/tokenb\x06proto3')
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,hfc_dot_protos_dot_token_dot_expectations__pb2.DESCRIPTOR,hfc_dot_protos_dot_token_dot_transaction__pb2.DESCRIPTOR,])




_TOKENTOISSUE = _descriptor.Descriptor(
  name='TokenToIssue',
  full_name='token.TokenToIssue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='recipient', full_name='token.TokenToIssue.recipient', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='token.TokenToIssue.type', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='quantity', full_name='token.TokenToIssue.quantity', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=146,
  serialized_end=211,
)


_RECIPIENTTRANSFERSHARE = _descriptor.Descriptor(
  name='RecipientTransferShare',
  full_name='token.RecipientTransferShare',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='recipient', full_name='token.RecipientTransferShare.recipient', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='quantity', full_name='token.RecipientTransferShare.quantity', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=213,
  serialized_end=274,
)


_TOKENOUTPUT = _descriptor.Descriptor(
  name='TokenOutput',
  full_name='token.TokenOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='token.TokenOutput.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='token.TokenOutput.type', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='quantity', full_name='token.TokenOutput.quantity', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=276,
  serialized_end=349,
)


_UNSPENTTOKENS = _descriptor.Descriptor(
  name='UnspentTokens',
  full_name='token.UnspentTokens',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tokens', full_name='token.UnspentTokens.tokens', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=351,
  serialized_end=402,
)


_LISTREQUEST = _descriptor.Descriptor(
  name='ListRequest',
  full_name='token.ListRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='credential', full_name='token.ListRequest.credential', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=404,
  serialized_end=437,
)


_IMPORTREQUEST = _descriptor.Descriptor(
  name='ImportRequest',
  full_name='token.ImportRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='credential', full_name='token.ImportRequest.credential', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tokens_to_issue', full_name='token.ImportRequest.tokens_to_issue', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=439,
  serialized_end=520,
)


_TRANSFERREQUEST = _descriptor.Descriptor(
  name='TransferRequest',
  full_name='token.TransferRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='credential', full_name='token.TransferRequest.credential', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='token_ids', full_name='token.TransferRequest.token_ids', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='shares', full_name='token.TransferRequest.shares', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=522,
  serialized_end=641,
)


_REDEEMREQUEST = _descriptor.Descriptor(
  name='RedeemRequest',
  full_name='token.RedeemRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='credential', full_name='token.RedeemRequest.credential', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='token_ids', full_name='token.RedeemRequest.token_ids', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='quantity_to_redeem', full_name='token.RedeemRequest.quantity_to_redeem', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=643,
  serialized_end=741,
)


_ALLOWANCERECIPIENTSHARE = _descriptor.Descriptor(
  name='AllowanceRecipientShare',
  full_name='token.AllowanceRecipientShare',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='recipient', full_name='token.AllowanceRecipientShare.recipient', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='quantity', full_name='token.AllowanceRecipientShare.quantity', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=743,
  serialized_end=805,
)


_APPROVEREQUEST = _descriptor.Descriptor(
  name='ApproveRequest',
  full_name='token.ApproveRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='credential', full_name='token.ApproveRequest.credential', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='allowance_shares', full_name='token.ApproveRequest.allowance_shares', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='token_ids', full_name='token.ApproveRequest.token_ids', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=808,
  serialized_end=937,
)


_EXPECTATIONREQUEST = _descriptor.Descriptor(
  name='ExpectationRequest',
  full_name='token.ExpectationRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='credential', full_name='token.ExpectationRequest.credential', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='expectation', full_name='token.ExpectationRequest.expectation', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='token_ids', full_name='token.ExpectationRequest.token_ids', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=939,
  serialized_end=1060,
)


_HEADER = _descriptor.Descriptor(
  name='Header',
  full_name='token.Header',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='token.Header.timestamp', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='channel_id', full_name='token.Header.channel_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='nonce', full_name='token.Header.nonce', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='creator', full_name='token.Header.creator', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tls_cert_hash', full_name='token.Header.tls_cert_hash', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1063,
  serialized_end=1193,
)


_COMMAND = _descriptor.Descriptor(
  name='Command',
  full_name='token.Command',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='token.Command.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='import_request', full_name='token.Command.import_request', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='transfer_request', full_name='token.Command.transfer_request', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='list_request', full_name='token.Command.list_request', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='redeem_request', full_name='token.Command.redeem_request', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='approve_request', full_name='token.Command.approve_request', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='transfer_from_request', full_name='token.Command.transfer_from_request', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='expectation_request', full_name='token.Command.expectation_request', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='payload', full_name='token.Command.payload',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=1196,
  serialized_end=1604,
)


_SIGNEDCOMMAND = _descriptor.Descriptor(
  name='SignedCommand',
  full_name='token.SignedCommand',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='command', full_name='token.SignedCommand.command', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='signature', full_name='token.SignedCommand.signature', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1606,
  serialized_end=1657,
)


_COMMANDRESPONSEHEADER = _descriptor.Descriptor(
  name='CommandResponseHeader',
  full_name='token.CommandResponseHeader',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='token.CommandResponseHeader.timestamp', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='command_hash', full_name='token.CommandResponseHeader.command_hash', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='creator', full_name='token.CommandResponseHeader.creator', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1659,
  serialized_end=1768,
)


_ERROR = _descriptor.Descriptor(
  name='Error',
  full_name='token.Error',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='message', full_name='token.Error.message', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='payload', full_name='token.Error.payload', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1770,
  serialized_end=1811,
)


_COMMANDRESPONSE = _descriptor.Descriptor(
  name='CommandResponse',
  full_name='token.CommandResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='token.CommandResponse.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='err', full_name='token.CommandResponse.err', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='token_transaction', full_name='token.CommandResponse.token_transaction', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unspent_tokens', full_name='token.CommandResponse.unspent_tokens', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='payload', full_name='token.CommandResponse.payload',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=1814,
  serialized_end=2019,
)


_SIGNEDCOMMANDRESPONSE = _descriptor.Descriptor(
  name='SignedCommandResponse',
  full_name='token.SignedCommandResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='token.SignedCommandResponse.response', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='signature', full_name='token.SignedCommandResponse.signature', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2021,
  serialized_end=2081,
)

_TOKENOUTPUT.fields_by_name['id'].message_type = hfc_dot_protos_dot_token_dot_transaction__pb2._INPUTID
_UNSPENTTOKENS.fields_by_name['tokens'].message_type = _TOKENOUTPUT
_IMPORTREQUEST.fields_by_name['tokens_to_issue'].message_type = _TOKENTOISSUE
_TRANSFERREQUEST.fields_by_name['token_ids'].message_type = hfc_dot_protos_dot_token_dot_transaction__pb2._INPUTID
_TRANSFERREQUEST.fields_by_name['shares'].message_type = _RECIPIENTTRANSFERSHARE
_REDEEMREQUEST.fields_by_name['token_ids'].message_type = hfc_dot_protos_dot_token_dot_transaction__pb2._INPUTID
_APPROVEREQUEST.fields_by_name['allowance_shares'].message_type = _ALLOWANCERECIPIENTSHARE
_APPROVEREQUEST.fields_by_name['token_ids'].message_type = hfc_dot_protos_dot_token_dot_transaction__pb2._INPUTID
_EXPECTATIONREQUEST.fields_by_name['expectation'].message_type = hfc_dot_protos_dot_token_dot_expectations__pb2._TOKENEXPECTATION
_EXPECTATIONREQUEST.fields_by_name['token_ids'].message_type = hfc_dot_protos_dot_token_dot_transaction__pb2._INPUTID
_HEADER.fields_by_name['timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_COMMAND.fields_by_name['header'].message_type = _HEADER
_COMMAND.fields_by_name['import_request'].message_type = _IMPORTREQUEST
_COMMAND.fields_by_name['transfer_request'].message_type = _TRANSFERREQUEST
_COMMAND.fields_by_name['list_request'].message_type = _LISTREQUEST
_COMMAND.fields_by_name['redeem_request'].message_type = _REDEEMREQUEST
_COMMAND.fields_by_name['approve_request'].message_type = _APPROVEREQUEST
_COMMAND.fields_by_name['transfer_from_request'].message_type = _TRANSFERREQUEST
_COMMAND.fields_by_name['expectation_request'].message_type = _EXPECTATIONREQUEST
_COMMAND.oneofs_by_name['payload'].fields.append(
  _COMMAND.fields_by_name['import_request'])
_COMMAND.fields_by_name['import_request'].containing_oneof = _COMMAND.oneofs_by_name['payload']
_COMMAND.oneofs_by_name['payload'].fields.append(
  _COMMAND.fields_by_name['transfer_request'])
_COMMAND.fields_by_name['transfer_request'].containing_oneof = _COMMAND.oneofs_by_name['payload']
_COMMAND.oneofs_by_name['payload'].fields.append(
  _COMMAND.fields_by_name['list_request'])
_COMMAND.fields_by_name['list_request'].containing_oneof = _COMMAND.oneofs_by_name['payload']
_COMMAND.oneofs_by_name['payload'].fields.append(
  _COMMAND.fields_by_name['redeem_request'])
_COMMAND.fields_by_name['redeem_request'].containing_oneof = _COMMAND.oneofs_by_name['payload']
_COMMAND.oneofs_by_name['payload'].fields.append(
  _COMMAND.fields_by_name['approve_request'])
_COMMAND.fields_by_name['approve_request'].containing_oneof = _COMMAND.oneofs_by_name['payload']
_COMMAND.oneofs_by_name['payload'].fields.append(
  _COMMAND.fields_by_name['transfer_from_request'])
_COMMAND.fields_by_name['transfer_from_request'].containing_oneof = _COMMAND.oneofs_by_name['payload']
_COMMAND.oneofs_by_name['payload'].fields.append(
  _COMMAND.fields_by_name['expectation_request'])
_COMMAND.fields_by_name['expectation_request'].containing_oneof = _COMMAND.oneofs_by_name['payload']
_COMMANDRESPONSEHEADER.fields_by_name['timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_COMMANDRESPONSE.fields_by_name['header'].message_type = _COMMANDRESPONSEHEADER
_COMMANDRESPONSE.fields_by_name['err'].message_type = _ERROR
_COMMANDRESPONSE.fields_by_name['token_transaction'].message_type = hfc_dot_protos_dot_token_dot_transaction__pb2._TOKENTRANSACTION
_COMMANDRESPONSE.fields_by_name['unspent_tokens'].message_type = _UNSPENTTOKENS
_COMMANDRESPONSE.oneofs_by_name['payload'].fields.append(
  _COMMANDRESPONSE.fields_by_name['err'])
_COMMANDRESPONSE.fields_by_name['err'].containing_oneof = _COMMANDRESPONSE.oneofs_by_name['payload']
_COMMANDRESPONSE.oneofs_by_name['payload'].fields.append(
  _COMMANDRESPONSE.fields_by_name['token_transaction'])
_COMMANDRESPONSE.fields_by_name['token_transaction'].containing_oneof = _COMMANDRESPONSE.oneofs_by_name['payload']
_COMMANDRESPONSE.oneofs_by_name['payload'].fields.append(
  _COMMANDRESPONSE.fields_by_name['unspent_tokens'])
_COMMANDRESPONSE.fields_by_name['unspent_tokens'].containing_oneof = _COMMANDRESPONSE.oneofs_by_name['payload']
DESCRIPTOR.message_types_by_name['TokenToIssue'] = _TOKENTOISSUE
DESCRIPTOR.message_types_by_name['RecipientTransferShare'] = _RECIPIENTTRANSFERSHARE
DESCRIPTOR.message_types_by_name['TokenOutput'] = _TOKENOUTPUT
DESCRIPTOR.message_types_by_name['UnspentTokens'] = _UNSPENTTOKENS
DESCRIPTOR.message_types_by_name['ListRequest'] = _LISTREQUEST
DESCRIPTOR.message_types_by_name['ImportRequest'] = _IMPORTREQUEST
DESCRIPTOR.message_types_by_name['TransferRequest'] = _TRANSFERREQUEST
DESCRIPTOR.message_types_by_name['RedeemRequest'] = _REDEEMREQUEST
DESCRIPTOR.message_types_by_name['AllowanceRecipientShare'] = _ALLOWANCERECIPIENTSHARE
DESCRIPTOR.message_types_by_name['ApproveRequest'] = _APPROVEREQUEST
DESCRIPTOR.message_types_by_name['ExpectationRequest'] = _EXPECTATIONREQUEST
DESCRIPTOR.message_types_by_name['Header'] = _HEADER
DESCRIPTOR.message_types_by_name['Command'] = _COMMAND
DESCRIPTOR.message_types_by_name['SignedCommand'] = _SIGNEDCOMMAND
DESCRIPTOR.message_types_by_name['CommandResponseHeader'] = _COMMANDRESPONSEHEADER
DESCRIPTOR.message_types_by_name['Error'] = _ERROR
DESCRIPTOR.message_types_by_name['CommandResponse'] = _COMMANDRESPONSE
DESCRIPTOR.message_types_by_name['SignedCommandResponse'] = _SIGNEDCOMMANDRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TokenToIssue = _reflection.GeneratedProtocolMessageType('TokenToIssue', (_message.Message,), dict(
  DESCRIPTOR = _TOKENTOISSUE,
  __module__ = 'hfc.protos.token.prover_pb2'
  # @@protoc_insertion_point(class_scope:token.TokenToIssue)
  ))
_sym_db.RegisterMessage(TokenToIssue)

RecipientTransferShare = _reflection.GeneratedProtocolMessageType('RecipientTransferShare', (_message.Message,), dict(
  DESCRIPTOR = _RECIPIENTTRANSFERSHARE,
  __module__ = 'hfc.protos.token.prover_pb2'
  # @@protoc_insertion_point(class_scope:token.RecipientTransferShare)
  ))
_sym_db.RegisterMessage(RecipientTransferShare)

TokenOutput = _reflection.GeneratedProtocolMessageType('TokenOutput', (_message.Message,), dict(
  DESCRIPTOR = _TOKENOUTPUT,
  __module__ = 'hfc.protos.token.prover_pb2'
  # @@protoc_insertion_point(class_scope:token.TokenOutput)
  ))
_sym_db.RegisterMessage(TokenOutput)

UnspentTokens = _reflection.GeneratedProtocolMessageType('UnspentTokens', (_message.Message,), dict(
  DESCRIPTOR = _UNSPENTTOKENS,
  __module__ = 'hfc.protos.token.prover_pb2'
  # @@protoc_insertion_point(class_scope:token.UnspentTokens)
  ))
_sym_db.RegisterMessage(UnspentTokens)

ListRequest = _reflection.GeneratedProtocolMessageType('ListRequest', (_message.Message,), dict(
  DESCRIPTOR = _LISTREQUEST,
  __module__ = 'hfc.protos.token.prover_pb2'
  # @@protoc_insertion_point(class_scope:token.ListRequest)
  ))
_sym_db.RegisterMessage(ListRequest)

ImportRequest = _reflection.GeneratedProtocolMessageType('ImportRequest', (_message.Message,), dict(
  DESCRIPTOR = _IMPORTREQUEST,
  __module__ = 'hfc.protos.token.prover_pb2'
  # @@protoc_insertion_point(class_scope:token.ImportRequest)
  ))
_sym_db.RegisterMessage(ImportRequest)

TransferRequest = _reflection.GeneratedProtocolMessageType('TransferRequest', (_message.Message,), dict(
  DESCRIPTOR = _TRANSFERREQUEST,
  __module__ = 'hfc.protos.token.prover_pb2'
  # @@protoc_insertion_point(class_scope:token.TransferRequest)
  ))
_sym_db.RegisterMessage(TransferRequest)

RedeemRequest = _reflection.GeneratedProtocolMessageType('RedeemRequest', (_message.Message,), dict(
  DESCRIPTOR = _REDEEMREQUEST,
  __module__ = 'hfc.protos.token.prover_pb2'
  # @@protoc_insertion_point(class_scope:token.RedeemRequest)
  ))
_sym_db.RegisterMessage(RedeemRequest)

AllowanceRecipientShare = _reflection.GeneratedProtocolMessageType('AllowanceRecipientShare', (_message.Message,), dict(
  DESCRIPTOR = _ALLOWANCERECIPIENTSHARE,
  __module__ = 'hfc.protos.token.prover_pb2'
  # @@protoc_insertion_point(class_scope:token.AllowanceRecipientShare)
  ))
_sym_db.RegisterMessage(AllowanceRecipientShare)

ApproveRequest = _reflection.GeneratedProtocolMessageType('ApproveRequest', (_message.Message,), dict(
  DESCRIPTOR = _APPROVEREQUEST,
  __module__ = 'hfc.protos.token.prover_pb2'
  # @@protoc_insertion_point(class_scope:token.ApproveRequest)
  ))
_sym_db.RegisterMessage(ApproveRequest)

ExpectationRequest = _reflection.GeneratedProtocolMessageType('ExpectationRequest', (_message.Message,), dict(
  DESCRIPTOR = _EXPECTATIONREQUEST,
  __module__ = 'hfc.protos.token.prover_pb2'
  # @@protoc_insertion_point(class_scope:token.ExpectationRequest)
  ))
_sym_db.RegisterMessage(ExpectationRequest)

Header = _reflection.GeneratedProtocolMessageType('Header', (_message.Message,), dict(
  DESCRIPTOR = _HEADER,
  __module__ = 'hfc.protos.token.prover_pb2'
  # @@protoc_insertion_point(class_scope:token.Header)
  ))
_sym_db.RegisterMessage(Header)

Command = _reflection.GeneratedProtocolMessageType('Command', (_message.Message,), dict(
  DESCRIPTOR = _COMMAND,
  __module__ = 'hfc.protos.token.prover_pb2'
  # @@protoc_insertion_point(class_scope:token.Command)
  ))
_sym_db.RegisterMessage(Command)

SignedCommand = _reflection.GeneratedProtocolMessageType('SignedCommand', (_message.Message,), dict(
  DESCRIPTOR = _SIGNEDCOMMAND,
  __module__ = 'hfc.protos.token.prover_pb2'
  # @@protoc_insertion_point(class_scope:token.SignedCommand)
  ))
_sym_db.RegisterMessage(SignedCommand)

CommandResponseHeader = _reflection.GeneratedProtocolMessageType('CommandResponseHeader', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDRESPONSEHEADER,
  __module__ = 'hfc.protos.token.prover_pb2'
  # @@protoc_insertion_point(class_scope:token.CommandResponseHeader)
  ))
_sym_db.RegisterMessage(CommandResponseHeader)

Error = _reflection.GeneratedProtocolMessageType('Error', (_message.Message,), dict(
  DESCRIPTOR = _ERROR,
  __module__ = 'hfc.protos.token.prover_pb2'
  # @@protoc_insertion_point(class_scope:token.Error)
  ))
_sym_db.RegisterMessage(Error)

CommandResponse = _reflection.GeneratedProtocolMessageType('CommandResponse', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDRESPONSE,
  __module__ = 'hfc.protos.token.prover_pb2'
  # @@protoc_insertion_point(class_scope:token.CommandResponse)
  ))
_sym_db.RegisterMessage(CommandResponse)

SignedCommandResponse = _reflection.GeneratedProtocolMessageType('SignedCommandResponse', (_message.Message,), dict(
  DESCRIPTOR = _SIGNEDCOMMANDRESPONSE,
  __module__ = 'hfc.protos.token.prover_pb2'
  # @@protoc_insertion_point(class_scope:token.SignedCommandResponse)
  ))
_sym_db.RegisterMessage(SignedCommandResponse)


DESCRIPTOR._options = None

_PROVER = _descriptor.ServiceDescriptor(
  name='Prover',
  full_name='token.Prover',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=2083,
  serialized_end=2163,
  methods=[
  _descriptor.MethodDescriptor(
    name='ProcessCommand',
    full_name='token.Prover.ProcessCommand',
    index=0,
    containing_service=None,
    input_type=_SIGNEDCOMMAND,
    output_type=_SIGNEDCOMMANDRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_PROVER)

DESCRIPTOR.services_by_name['Prover'] = _PROVER

# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: hfc/protos/peer/query.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='hfc/protos/peer/query.proto',
  package='protos',
  syntax='proto3',
  serialized_options=_b('\n\"org.hyperledger.fabric.protos.peerZ)github.com/hyperledger/fabric/protos/peer'),
  serialized_pb=_b('\n\x1bhfc/protos/peer/query.proto\x12\x06protos\"C\n\x16\x43haincodeQueryResponse\x12)\n\nchaincodes\x18\x01 \x03(\x0b\x32\x15.protos.ChaincodeInfo\"s\n\rChaincodeInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x0c\n\x04path\x18\x03 \x01(\t\x12\r\n\x05input\x18\x04 \x01(\t\x12\x0c\n\x04\x65scc\x18\x05 \x01(\t\x12\x0c\n\x04vscc\x18\x06 \x01(\t\x12\n\n\x02id\x18\x07 \x01(\x0c\"=\n\x14\x43hannelQueryResponse\x12%\n\x08\x63hannels\x18\x01 \x03(\x0b\x32\x13.protos.ChannelInfo\"!\n\x0b\x43hannelInfo\x12\x12\n\nchannel_id\x18\x01 \x01(\tBO\n\"org.hyperledger.fabric.protos.peerZ)github.com/hyperledger/fabric/protos/peerb\x06proto3')
)




_CHAINCODEQUERYRESPONSE = _descriptor.Descriptor(
  name='ChaincodeQueryResponse',
  full_name='protos.ChaincodeQueryResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='chaincodes', full_name='protos.ChaincodeQueryResponse.chaincodes', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=39,
  serialized_end=106,
)


_CHAINCODEINFO = _descriptor.Descriptor(
  name='ChaincodeInfo',
  full_name='protos.ChaincodeInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='protos.ChaincodeInfo.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='version', full_name='protos.ChaincodeInfo.version', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='path', full_name='protos.ChaincodeInfo.path', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='input', full_name='protos.ChaincodeInfo.input', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='escc', full_name='protos.ChaincodeInfo.escc', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='vscc', full_name='protos.ChaincodeInfo.vscc', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='protos.ChaincodeInfo.id', index=6,
      number=7, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=108,
  serialized_end=223,
)


_CHANNELQUERYRESPONSE = _descriptor.Descriptor(
  name='ChannelQueryResponse',
  full_name='protos.ChannelQueryResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='channels', full_name='protos.ChannelQueryResponse.channels', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=225,
  serialized_end=286,
)


_CHANNELINFO = _descriptor.Descriptor(
  name='ChannelInfo',
  full_name='protos.ChannelInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='channel_id', full_name='protos.ChannelInfo.channel_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=288,
  serialized_end=321,
)

_CHAINCODEQUERYRESPONSE.fields_by_name['chaincodes'].message_type = _CHAINCODEINFO
_CHANNELQUERYRESPONSE.fields_by_name['channels'].message_type = _CHANNELINFO
DESCRIPTOR.message_types_by_name['ChaincodeQueryResponse'] = _CHAINCODEQUERYRESPONSE
DESCRIPTOR.message_types_by_name['ChaincodeInfo'] = _CHAINCODEINFO
DESCRIPTOR.message_types_by_name['ChannelQueryResponse'] = _CHANNELQUERYRESPONSE
DESCRIPTOR.message_types_by_name['ChannelInfo'] = _CHANNELINFO
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ChaincodeQueryResponse = _reflection.GeneratedProtocolMessageType('ChaincodeQueryResponse', (_message.Message,), dict(
  DESCRIPTOR = _CHAINCODEQUERYRESPONSE,
  __module__ = 'hfc.protos.peer.query_pb2'
  # @@protoc_insertion_point(class_scope:protos.ChaincodeQueryResponse)
  ))
_sym_db.RegisterMessage(ChaincodeQueryResponse)

ChaincodeInfo = _reflection.GeneratedProtocolMessageType('ChaincodeInfo', (_message.Message,), dict(
  DESCRIPTOR = _CHAINCODEINFO,
  __module__ = 'hfc.protos.peer.query_pb2'
  # @@protoc_insertion_point(class_scope:protos.ChaincodeInfo)
  ))
_sym_db.RegisterMessage(ChaincodeInfo)

ChannelQueryResponse = _reflection.GeneratedProtocolMessageType('ChannelQueryResponse', (_message.Message,), dict(
  DESCRIPTOR = _CHANNELQUERYRESPONSE,
  __module__ = 'hfc.protos.peer.query_pb2'
  # @@protoc_insertion_point(class_scope:protos.ChannelQueryResponse)
  ))
_sym_db.RegisterMessage(ChannelQueryResponse)

ChannelInfo = _reflection.GeneratedProtocolMessageType('ChannelInfo', (_message.Message,), dict(
  DESCRIPTOR = _CHANNELINFO,
  __module__ = 'hfc.protos.peer.query_pb2'
  # @@protoc_insertion_point(class_scope:protos.ChannelInfo)
  ))
_sym_db.RegisterMessage(ChannelInfo)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: hfc/protos/peer/lifecycle/lifecycle.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='hfc/protos/peer/lifecycle/lifecycle.proto',
  package='lifecycle',
  syntax='proto3',
  serialized_options=_b('\n,org.hyperledger.fabric.protos.peer.lifecycleZ3github.com/hyperledger/fabric/protos/peer/lifecycle'),
  serialized_pb=_b('\n)hfc/protos/peer/lifecycle/lifecycle.proto\x12\tlifecycle\"X\n\x14InstallChaincodeArgs\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12!\n\x19\x63haincode_install_package\x18\x03 \x01(\x0c\"&\n\x16InstallChaincodeResult\x12\x0c\n\x04hash\x18\x01 \x01(\x0c\"<\n\x1bQueryInstalledChaincodeArgs\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\"-\n\x1dQueryInstalledChaincodeResult\x12\x0c\n\x04hash\x18\x01 \x01(\x0c\x42\x63\n,org.hyperledger.fabric.protos.peer.lifecycleZ3github.com/hyperledger/fabric/protos/peer/lifecycleb\x06proto3')
)




_INSTALLCHAINCODEARGS = _descriptor.Descriptor(
  name='InstallChaincodeArgs',
  full_name='lifecycle.InstallChaincodeArgs',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='lifecycle.InstallChaincodeArgs.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='version', full_name='lifecycle.InstallChaincodeArgs.version', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='chaincode_install_package', full_name='lifecycle.InstallChaincodeArgs.chaincode_install_package', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=56,
  serialized_end=144,
)


_INSTALLCHAINCODERESULT = _descriptor.Descriptor(
  name='InstallChaincodeResult',
  full_name='lifecycle.InstallChaincodeResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='hash', full_name='lifecycle.InstallChaincodeResult.hash', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=146,
  serialized_end=184,
)


_QUERYINSTALLEDCHAINCODEARGS = _descriptor.Descriptor(
  name='QueryInstalledChaincodeArgs',
  full_name='lifecycle.QueryInstalledChaincodeArgs',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='lifecycle.QueryInstalledChaincodeArgs.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='version', full_name='lifecycle.QueryInstalledChaincodeArgs.version', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=186,
  serialized_end=246,
)


_QUERYINSTALLEDCHAINCODERESULT = _descriptor.Descriptor(
  name='QueryInstalledChaincodeResult',
  full_name='lifecycle.QueryInstalledChaincodeResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='hash', full_name='lifecycle.QueryInstalledChaincodeResult.hash', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=248,
  serialized_end=293,
)

DESCRIPTOR.message_types_by_name['InstallChaincodeArgs'] = _INSTALLCHAINCODEARGS
DESCRIPTOR.message_types_by_name['InstallChaincodeResult'] = _INSTALLCHAINCODERESULT
DESCRIPTOR.message_types_by_name['QueryInstalledChaincodeArgs'] = _QUERYINSTALLEDCHAINCODEARGS
DESCRIPTOR.message_types_by_name['QueryInstalledChaincodeResult'] = _QUERYINSTALLEDCHAINCODERESULT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

InstallChaincodeArgs = _reflection.GeneratedProtocolMessageType('InstallChaincodeArgs', (_message.Message,), dict(
  DESCRIPTOR = _INSTALLCHAINCODEARGS,
  __module__ = 'hfc.protos.peer.lifecycle.lifecycle_pb2'
  # @@protoc_insertion_point(class_scope:lifecycle.InstallChaincodeArgs)
  ))
_sym_db.RegisterMessage(InstallChaincodeArgs)

InstallChaincodeResult = _reflection.GeneratedProtocolMessageType('InstallChaincodeResult', (_message.Message,), dict(
  DESCRIPTOR = _INSTALLCHAINCODERESULT,
  __module__ = 'hfc.protos.peer.lifecycle.lifecycle_pb2'
  # @@protoc_insertion_point(class_scope:lifecycle.InstallChaincodeResult)
  ))
_sym_db.RegisterMessage(InstallChaincodeResult)

QueryInstalledChaincodeArgs = _reflection.GeneratedProtocolMessageType('QueryInstalledChaincodeArgs', (_message.Message,), dict(
  DESCRIPTOR = _QUERYINSTALLEDCHAINCODEARGS,
  __module__ = 'hfc.protos.peer.lifecycle.lifecycle_pb2'
  # @@protoc_insertion_point(class_scope:lifecycle.QueryInstalledChaincodeArgs)
  ))
_sym_db.RegisterMessage(QueryInstalledChaincodeArgs)

QueryInstalledChaincodeResult = _reflection.GeneratedProtocolMessageType('QueryInstalledChaincodeResult', (_message.Message,), dict(
  DESCRIPTOR = _QUERYINSTALLEDCHAINCODERESULT,
  __module__ = 'hfc.protos.peer.lifecycle.lifecycle_pb2'
  # @@protoc_insertion_point(class_scope:lifecycle.QueryInstalledChaincodeResult)
  ))
_sym_db.RegisterMessage(QueryInstalledChaincodeResult)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: hfc/protos/peer/policy.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from hfc.protos.common import policies_pb2 as hfc_dot_protos_dot_common_dot_policies__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='hfc/protos/peer/policy.proto',
  package='protos',
  syntax='proto3',
  serialized_options=_b('\n\"org.hyperledger.fabric.protos.peerZ)github.com/hyperledger/fabric/protos/peer'),
  serialized_pb=_b('\n\x1chfc/protos/peer/policy.proto\x12\x06protos\x1a hfc/protos/common/policies.proto\"\x83\x01\n\x11\x41pplicationPolicy\x12;\n\x10signature_policy\x18\x01 \x01(\x0b\x32\x1f.common.SignaturePolicyEnvelopeH\x00\x12)\n\x1f\x63hannel_config_policy_reference\x18\x02 \x01(\tH\x00\x42\x06\n\x04TypeBO\n\"org.hyperledger.fabric.protos.peerZ)github.com/hyperledger/fabric/protos/peerb\x06proto3')
  ,
  dependencies=[hfc_dot_protos_dot_common_dot_policies__pb2.DESCRIPTOR,])




_APPLICATIONPOLICY = _descriptor.Descriptor(
  name='ApplicationPolicy',
  full_name='protos.ApplicationPolicy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='signature_policy', full_name='protos.ApplicationPolicy.signature_policy', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='channel_config_policy_reference', full_name='protos.ApplicationPolicy.channel_config_policy_reference', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='Type', full_name='protos.ApplicationPolicy.Type',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=75,
  serialized_end=206,
)

_APPLICATIONPOLICY.fields_by_name['signature_policy'].message_type = hfc_dot_protos_dot_common_dot_policies__pb2._SIGNATUREPOLICYENVELOPE
_APPLICATIONPOLICY.oneofs_by_name['Type'].fields.append(
  _APPLICATIONPOLICY.fields_by_name['signature_policy'])
_APPLICATIONPOLICY.fields_by_name['signature_policy'].containing_oneof = _APPLICATIONPOLICY.oneofs_by_name['Type']
_APPLICATIONPOLICY.oneofs_by_name['Type'].fields.append(
  _APPLICATIONPOLICY.fields_by_name['channel_config_policy_reference'])
_APPLICATIONPOLICY.fields_by_name['channel_config_policy_reference'].containing_oneof = _APPLICATIONPOLICY.oneofs_by_name['Type']
DESCRIPTOR.message_types_by_name['ApplicationPolicy'] = _APPLICATIONPOLICY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ApplicationPolicy = _reflection.GeneratedProtocolMessageType('ApplicationPolicy', (_message.Message,), dict(
  DESCRIPTOR = _APPLICATIONPOLICY,
  __module__ = 'hfc.protos.peer.policy_pb2'
  # @@protoc_insertion_point(class_scope:protos.ApplicationPolicy)
  ))
_sym_db.RegisterMessage(ApplicationPolicy)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# Copyright IBM Corp. 2017 All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#


class ChannelConfiguration(object):
    """A class represents channel configuration bytes."""

    def __init__(self, config=None, file_path=None):
        """Construct ChannelConfiguration by args.
        :param config: raw config bytes
        :param file_path: config file path
        :return:
        """
        self._config = None

        if file_path:
            with open(file_path, mode='rb') as file:
                self._config = file.read()

        if config:
            self._config = config

    @property
    def config(self):
        """Get config bytes.
        :return: raw config bytes
        """
        return self._config

    @config.setter
    def config(self, config):
        """Set config bytes.
        :param config: raw config bytes
        :return:
        """
        self._config = config



import couchdb

from cryptography.hazmat.backends import default_backend
from cryptography.hazmat.primitives import serialization
from cryptography.hazmat.primitives.serialization import load_pem_private_key

from hfc.fabric_ca.caservice import Enrollment
from hfc.fabric.user import User
from hfc.fabric.user import validate
from hfc.util.crypto.crypto import ecies


class CouchDBWalletStore(object):
    """CouchDBWalletStore stores the identities of users and admins
        in a CouchDB with given config
        ie. it contains the Private Key and Enrollment Certificate
    """

    def __init__(self, dbName, config='http://localhost:5984'):
        self.server = couchdb.Server(config)
        try:
            self.db = self.server[dbName]
        except Exception:
            self.db = self.server.create(dbName)

    def exists(self, enrollment_id):
        """Returns whether or not the creds of a user with a given user_id
            exists in the wallet

        :param enrollment_id: enrollment id
        :return: True or False
        """
        try:
            self.db[enrollment_id]
            return True
        except Exception:
            return False

    def remove(self, enrollment_id):
        """deletes identities of user with given enrollment_id

        :param enrollment_id: enrollment id
        :return:
        """
        self.db.delete(self.db[enrollment_id])

    def put(self, enrollment_id, user_enrollment):
        """Saves the particular Identity in the wallet

        :param enrollment_id: enrollment id
        :param user_enrollment: Enrollment object
        :return:
        """
        if not isinstance(user_enrollment, Enrollment):
            raise ValueError('"user_enrollment" is not a valid Enrollment object')
        PrivateKey = user_enrollment.private_key.private_bytes(encoding=serialization.Encoding.PEM,
                                                               format=serialization.PrivateFormat.PKCS8,
                                                               encryption_algorithm=serialization.NoEncryption()
                                                               ).decode()
        EnrollmentCert = user_enrollment.cert.decode()
        doc = {'EnrollmentCert': EnrollmentCert, 'PrivateKey': PrivateKey}
        self.db[enrollment_id] = doc

    def create_user(self, enrollment_id, org, msp_id, state_store=None):
        """Returns an instance of a user whose identity
            is stored in the CouchDBWallet

        :param enrollment_id: enrollment id
        :param org: organization
        :param msp_id: MSP id
        :param state_store:  (Default value = None)
        :return: a validated user instance
        """
        crypto_suit = ecies()

        if not self.exists(enrollment_id):
            raise AttributeError('"user" does not exist')

        key_pem = self.db[enrollment_id]['PrivateKey']
        cert_pem = self.db[enrollment_id]['EnrollmentCert']

        private_key = load_pem_private_key(key_pem, None, default_backend())
        enrollment = Enrollment(private_key, cert_pem)

        user = User(enrollment_id, org, state_store)
        user.enrollment = enrollment
        user.msp_id = msp_id
        user.cryptoSuite = crypto_suit

        return validate(user)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: hfc/protos/ledger/queryresult/kv_query_result.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='hfc/protos/ledger/queryresult/kv_query_result.proto',
  package='queryresult',
  syntax='proto3',
  serialized_pb=_b('\n3hfc/protos/ledger/queryresult/kv_query_result.proto\x12\x0bqueryresult\x1a\x1fgoogle/protobuf/timestamp.proto\"3\n\x02KV\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\x0c\"q\n\x0fKeyModification\x12\r\n\x05tx_id\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c\x12-\n\ttimestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x11\n\tis_delete\x18\x04 \x01(\x08\x42k\n0org.hyperledger.fabric.protos.ledger.queryresultZ7github.com/hyperledger/fabric/protos/ledger/queryresultb\x06proto3')
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])




_KV = _descriptor.Descriptor(
  name='KV',
  full_name='queryresult.KV',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='queryresult.KV.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='key', full_name='queryresult.KV.key', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='queryresult.KV.value', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=101,
  serialized_end=152,
)


_KEYMODIFICATION = _descriptor.Descriptor(
  name='KeyModification',
  full_name='queryresult.KeyModification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tx_id', full_name='queryresult.KeyModification.tx_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='queryresult.KeyModification.value', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='queryresult.KeyModification.timestamp', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_delete', full_name='queryresult.KeyModification.is_delete', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=154,
  serialized_end=267,
)

_KEYMODIFICATION.fields_by_name['timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
DESCRIPTOR.message_types_by_name['KV'] = _KV
DESCRIPTOR.message_types_by_name['KeyModification'] = _KEYMODIFICATION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

KV = _reflection.GeneratedProtocolMessageType('KV', (_message.Message,), dict(
  DESCRIPTOR = _KV,
  __module__ = 'hfc.protos.ledger.queryresult.kv_query_result_pb2'
  # @@protoc_insertion_point(class_scope:queryresult.KV)
  ))
_sym_db.RegisterMessage(KV)

KeyModification = _reflection.GeneratedProtocolMessageType('KeyModification', (_message.Message,), dict(
  DESCRIPTOR = _KEYMODIFICATION,
  __module__ = 'hfc.protos.ledger.queryresult.kv_query_result_pb2'
  # @@protoc_insertion_point(class_scope:queryresult.KeyModification)
  ))
_sym_db.RegisterMessage(KeyModification)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n0org.hyperledger.fabric.protos.ledger.queryresultZ7github.com/hyperledger/fabric/protos/ledger/queryresult'))
# @@protoc_insertion_point(module_scope)



# Copyright IBM Corp. 2016 All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import os
import time
import unittest

from hfc.fabric_ca.caservice import CAService
from test.integration.utils import cli_call

with open(os.path.join(os.path.dirname(__file__),
                       "../fixtures/ca/enroll-csr.pem")) as f:
    test_pem = f.read()

ENROLLMENT_ID = "admin"
ENROLLMENT_SECRET = "adminpw"


class CertificateServiceTest(unittest.TestCase):
    """Test for ca module. """

    def setUp(self):
        self._enrollment_id = ENROLLMENT_ID
        self._enrollment_secret = ENROLLMENT_SECRET
        if os.getenv("CA_ADDR"):
            self._ca_server_address = os.getenv("CA_ADDR")
        else:
            self._ca_server_address = "localhost:7054"
        self.compose_file_path = os.path.normpath(
            os.path.join(os.path.dirname(__file__),
                         "../fixtures/ca/docker-compose.yml")
        )

        self.start_test_env()

        self._ca_service = CAService("http://" + self._ca_server_address)
        id = self._enrollment_id
        secret = self._enrollment_secret
        self._adminEnrollment = self._ca_service.enroll(id, secret)
        self._certificateService = self._ca_service.newCertificateService()

    def tearDown(self):
        self.shutdown_test_env()

    def start_test_env(self):
        cli_call(["docker-compose", "-f", self.compose_file_path, "up", "-d"])
        time.sleep(5)

    def shutdown_test_env(self):
        cli_call(["docker-compose", "-f", self.compose_file_path, "down"])

    def test_get_success(self):
        """Test create success.
        """
        res = self._certificateService.getCertificates(self._adminEnrollment)

        self.assertTrue(res['success'] is True)
        self.assertTrue(len(res['result']) > 0)


if __name__ == '__main__':
    unittest.main()



# Copyright IBM Corp. 2017 All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import logging

import rx

from hfc.fabric.channel.transactionproposals \
    import TransactionProposalHandler, TransactionProposalRequest, \
    check_tran_prop_request, \
    build_header, build_proposal, sign_proposal, CC_INVOKE
from hfc.protos.common import common_pb2
from hfc.protos.peer import chaincode_pb2
from hfc.util.crypto import crypto
from hfc.util.utils import proto_str, proto_b

# deprecated remain for new code

_logger = logging.getLogger(__name__ + ".invocation")


class Invocation(TransactionProposalHandler):
    """Chaincode invocation transaction proposal handler."""

    def handle(self, tran_prop_req, scheduler=None):
        """Execute chaincode invocation transaction proposal request.

        :param scheduler: see rx.Scheduler (Default value = None)
        :param tran_prop_req: chaincode invocation transaction proposal request
        :return: An rx.Observer wrapper of chaincode invocation response
        """
        return _invoke_chaincode(self._chain, tran_prop_req, scheduler)


def _create_invocation_proposal(tran_prop_req, chain):
    """Create a chaincode invocation proposal

    This involves assembling the proposal with the data (chaincodeID,
    chaincode invocation spec, etc.) and signing it using the private key
    corresponding to the ECert to sign.

    :param tran_prop_req: see TransactionProposalRequest
    :param chain: chain instance
    :return: The created Proposal instance or None.
    """
    args = ["invoke" if not tran_prop_req.fcn
            else tran_prop_req.fcn] + tran_prop_req.args

    if tran_prop_req.bytes_args:
        args += tran_prop_req.bytes_args

    header = build_header(tran_prop_req.signing_identity,
                          tran_prop_req.nonce,
                          common_pb2.ENDORSER_TRANSACTION,
                          chain,
                          tran_prop_req.prop_type,
                          chaincode_id=tran_prop_req.chaincode_id
                          )

    cci_spec = chaincode_pb2.ChaincodeInvocationSpec()
    cci_spec.chaincode_spec.type = \
        chaincode_pb2.ChaincodeSpec.Type.Value('GOLANG')
    cci_spec.chaincode_spec.chaincode_id.name = \
        proto_str(tran_prop_req.chaincode_id)
    cci_spec.chaincode_spec.chaincode_id.version = \
        proto_str(tran_prop_req.chaincode_version)
    cci_spec.chaincode_spec.input.args.extend(list(map(
        lambda x: proto_b(x), args)))
    proposal = build_proposal(cci_spec, header)

    signed_proposal = sign_proposal(
        tran_prop_req.signing_identity, proposal)
    return signed_proposal


def _invoke_chaincode(chain, cc_invocation_request, scheduler=None):
    """Invoke chaincode.

    :param chain: chain instance
    :param scheduler: see rx.Scheduler (Default value = None)
    :param cc_invocation_request: see TransactionProposalRequest
    :return: An rx.Observable of invocation response

    """
    if len(chain.peers) < 1:
        return rx.Observable.just(ValueError(
            "Missing peer objects on this chain"
        ))

    peers = {}
    if cc_invocation_request and cc_invocation_request.targets:
        peers = cc_invocation_request.targets
        for peer in peers:
            if not chain.is_valid_peer(peer):
                return rx.Observable.just(ValueError(
                    'Request targets peer object {} not in chain'.format(peer)
                ))

    if len(peers) < 1:
        peers = chain.peers

    return rx.Observable \
        .just(cc_invocation_request) \
        .map(check_tran_prop_request) \
        .map(lambda req, idx: _create_invocation_proposal(req, chain))
    # .flatmap(lambda proposal, idx:
    #          send_transaction_proposal(proposal, peers, scheduler))


def create_invocation_proposal_req(chaincode_id,
                                   chaincode_version, creator,
                                   fcn='invoke', args=None,
                                   nonce=crypto.generate_nonce(24),
                                   targets=None):
    """Create invocation proposal request.

    :param fcn: chaincode invoke function (Default value = 'invoke')
    :param args: invoke function args (Default value = None)
    :param targets: peers (Default value = None)
    :param nonce: nonce (Default value = crypto.generate_nonce(24))
    :param chaincode_id: chaincode_id
    :param chaincode_version: chaincode_version
    :param creator: user
    :return: see TransactionProposalRequest

    """
    return TransactionProposalRequest(chaincode_id, creator, CC_INVOKE,
                                      chaincode_version=chaincode_version,
                                      fcn=fcn, args=args,
                                      nonce=nonce, targets=targets)


def chaincode_invocation(chain):
    """Create invocation.

    :param chain: chain instance
    :return: Invocation instance

    """
    return Invocation(chain)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: hfc/protos/msp/msp_config.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='hfc/protos/msp/msp_config.proto',
  package='msp',
  syntax='proto3',
  serialized_options=_b('\n!org.hyperledger.fabric.protos.mspB\020MspConfigPackageZ(github.com/hyperledger/fabric/protos/msp'),
  serialized_pb=_b('\n\x1fhfc/protos/msp/msp_config.proto\x12\x03msp\")\n\tMSPConfig\x12\x0c\n\x04type\x18\x01 \x01(\x05\x12\x0e\n\x06\x63onfig\x18\x02 \x01(\x0c\"\x83\x03\n\x0f\x46\x61\x62ricMSPConfig\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x12\n\nroot_certs\x18\x02 \x03(\x0c\x12\x1a\n\x12intermediate_certs\x18\x03 \x03(\x0c\x12\x0e\n\x06\x61\x64mins\x18\x04 \x03(\x0c\x12\x17\n\x0frevocation_list\x18\x05 \x03(\x0c\x12\x32\n\x10signing_identity\x18\x06 \x01(\x0b\x32\x18.msp.SigningIdentityInfo\x12@\n\x1forganizational_unit_identifiers\x18\x07 \x03(\x0b\x32\x17.msp.FabricOUIdentifier\x12.\n\rcrypto_config\x18\x08 \x01(\x0b\x32\x17.msp.FabricCryptoConfig\x12\x16\n\x0etls_root_certs\x18\t \x03(\x0c\x12\x1e\n\x16tls_intermediate_certs\x18\n \x03(\x0c\x12+\n\x0f\x66\x61\x62ric_node_ous\x18\x0b \x01(\x0b\x32\x12.msp.FabricNodeOUs\"^\n\x12\x46\x61\x62ricCryptoConfig\x12\x1d\n\x15signature_hash_family\x18\x01 \x01(\t\x12)\n!identity_identifier_hash_function\x18\x02 \x01(\t\"~\n\x0fIdemixMSPConfig\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0b\n\x03ipk\x18\x02 \x01(\x0c\x12*\n\x06signer\x18\x03 \x01(\x0b\x32\x1a.msp.IdemixMSPSignerConfig\x12\x15\n\rrevocation_pk\x18\x04 \x01(\x0c\x12\r\n\x05\x65poch\x18\x05 \x01(\x03\"\xa9\x01\n\x15IdemixMSPSignerConfig\x12\x0c\n\x04\x63red\x18\x01 \x01(\x0c\x12\n\n\x02sk\x18\x02 \x01(\x0c\x12&\n\x1eorganizational_unit_identifier\x18\x03 \x01(\t\x12\x0c\n\x04role\x18\x04 \x01(\x05\x12\x15\n\renrollment_id\x18\x05 \x01(\t\x12)\n!credential_revocation_information\x18\x06 \x01(\x0c\"R\n\x13SigningIdentityInfo\x12\x15\n\rpublic_signer\x18\x01 \x01(\x0c\x12$\n\x0eprivate_signer\x18\x02 \x01(\x0b\x32\x0c.msp.KeyInfo\"7\n\x07KeyInfo\x12\x16\n\x0ekey_identifier\x18\x01 \x01(\t\x12\x14\n\x0ckey_material\x18\x02 \x01(\x0c\"Q\n\x12\x46\x61\x62ricOUIdentifier\x12\x13\n\x0b\x63\x65rtificate\x18\x01 \x01(\x0c\x12&\n\x1eorganizational_unit_identifier\x18\x02 \x01(\t\"\x8b\x01\n\rFabricNodeOUs\x12\x0e\n\x06\x65nable\x18\x01 \x01(\x08\x12\x35\n\x14\x63lient_ou_identifier\x18\x02 \x01(\x0b\x32\x17.msp.FabricOUIdentifier\x12\x33\n\x12peer_ou_identifier\x18\x03 \x01(\x0b\x32\x17.msp.FabricOUIdentifierB_\n!org.hyperledger.fabric.protos.mspB\x10MspConfigPackageZ(github.com/hyperledger/fabric/protos/mspb\x06proto3')
)




_MSPCONFIG = _descriptor.Descriptor(
  name='MSPConfig',
  full_name='msp.MSPConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='msp.MSPConfig.type', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='config', full_name='msp.MSPConfig.config', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=40,
  serialized_end=81,
)


_FABRICMSPCONFIG = _descriptor.Descriptor(
  name='FabricMSPConfig',
  full_name='msp.FabricMSPConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='msp.FabricMSPConfig.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='root_certs', full_name='msp.FabricMSPConfig.root_certs', index=1,
      number=2, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='intermediate_certs', full_name='msp.FabricMSPConfig.intermediate_certs', index=2,
      number=3, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='admins', full_name='msp.FabricMSPConfig.admins', index=3,
      number=4, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='revocation_list', full_name='msp.FabricMSPConfig.revocation_list', index=4,
      number=5, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='signing_identity', full_name='msp.FabricMSPConfig.signing_identity', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='organizational_unit_identifiers', full_name='msp.FabricMSPConfig.organizational_unit_identifiers', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='crypto_config', full_name='msp.FabricMSPConfig.crypto_config', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tls_root_certs', full_name='msp.FabricMSPConfig.tls_root_certs', index=8,
      number=9, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tls_intermediate_certs', full_name='msp.FabricMSPConfig.tls_intermediate_certs', index=9,
      number=10, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fabric_node_ous', full_name='msp.FabricMSPConfig.fabric_node_ous', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=84,
  serialized_end=471,
)


_FABRICCRYPTOCONFIG = _descriptor.Descriptor(
  name='FabricCryptoConfig',
  full_name='msp.FabricCryptoConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='signature_hash_family', full_name='msp.FabricCryptoConfig.signature_hash_family', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='identity_identifier_hash_function', full_name='msp.FabricCryptoConfig.identity_identifier_hash_function', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=473,
  serialized_end=567,
)


_IDEMIXMSPCONFIG = _descriptor.Descriptor(
  name='IdemixMSPConfig',
  full_name='msp.IdemixMSPConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='msp.IdemixMSPConfig.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ipk', full_name='msp.IdemixMSPConfig.ipk', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='signer', full_name='msp.IdemixMSPConfig.signer', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='revocation_pk', full_name='msp.IdemixMSPConfig.revocation_pk', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='epoch', full_name='msp.IdemixMSPConfig.epoch', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=569,
  serialized_end=695,
)


_IDEMIXMSPSIGNERCONFIG = _descriptor.Descriptor(
  name='IdemixMSPSignerConfig',
  full_name='msp.IdemixMSPSignerConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='cred', full_name='msp.IdemixMSPSignerConfig.cred', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sk', full_name='msp.IdemixMSPSignerConfig.sk', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='organizational_unit_identifier', full_name='msp.IdemixMSPSignerConfig.organizational_unit_identifier', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='role', full_name='msp.IdemixMSPSignerConfig.role', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='enrollment_id', full_name='msp.IdemixMSPSignerConfig.enrollment_id', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='credential_revocation_information', full_name='msp.IdemixMSPSignerConfig.credential_revocation_information', index=5,
      number=6, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=698,
  serialized_end=867,
)


_SIGNINGIDENTITYINFO = _descriptor.Descriptor(
  name='SigningIdentityInfo',
  full_name='msp.SigningIdentityInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='public_signer', full_name='msp.SigningIdentityInfo.public_signer', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='private_signer', full_name='msp.SigningIdentityInfo.private_signer', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=869,
  serialized_end=951,
)


_KEYINFO = _descriptor.Descriptor(
  name='KeyInfo',
  full_name='msp.KeyInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key_identifier', full_name='msp.KeyInfo.key_identifier', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='key_material', full_name='msp.KeyInfo.key_material', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=953,
  serialized_end=1008,
)


_FABRICOUIDENTIFIER = _descriptor.Descriptor(
  name='FabricOUIdentifier',
  full_name='msp.FabricOUIdentifier',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='certificate', full_name='msp.FabricOUIdentifier.certificate', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='organizational_unit_identifier', full_name='msp.FabricOUIdentifier.organizational_unit_identifier', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1010,
  serialized_end=1091,
)


_FABRICNODEOUS = _descriptor.Descriptor(
  name='FabricNodeOUs',
  full_name='msp.FabricNodeOUs',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='enable', full_name='msp.FabricNodeOUs.enable', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='client_ou_identifier', full_name='msp.FabricNodeOUs.client_ou_identifier', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='peer_ou_identifier', full_name='msp.FabricNodeOUs.peer_ou_identifier', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1094,
  serialized_end=1233,
)

_FABRICMSPCONFIG.fields_by_name['signing_identity'].message_type = _SIGNINGIDENTITYINFO
_FABRICMSPCONFIG.fields_by_name['organizational_unit_identifiers'].message_type = _FABRICOUIDENTIFIER
_FABRICMSPCONFIG.fields_by_name['crypto_config'].message_type = _FABRICCRYPTOCONFIG
_FABRICMSPCONFIG.fields_by_name['fabric_node_ous'].message_type = _FABRICNODEOUS
_IDEMIXMSPCONFIG.fields_by_name['signer'].message_type = _IDEMIXMSPSIGNERCONFIG
_SIGNINGIDENTITYINFO.fields_by_name['private_signer'].message_type = _KEYINFO
_FABRICNODEOUS.fields_by_name['client_ou_identifier'].message_type = _FABRICOUIDENTIFIER
_FABRICNODEOUS.fields_by_name['peer_ou_identifier'].message_type = _FABRICOUIDENTIFIER
DESCRIPTOR.message_types_by_name['MSPConfig'] = _MSPCONFIG
DESCRIPTOR.message_types_by_name['FabricMSPConfig'] = _FABRICMSPCONFIG
DESCRIPTOR.message_types_by_name['FabricCryptoConfig'] = _FABRICCRYPTOCONFIG
DESCRIPTOR.message_types_by_name['IdemixMSPConfig'] = _IDEMIXMSPCONFIG
DESCRIPTOR.message_types_by_name['IdemixMSPSignerConfig'] = _IDEMIXMSPSIGNERCONFIG
DESCRIPTOR.message_types_by_name['SigningIdentityInfo'] = _SIGNINGIDENTITYINFO
DESCRIPTOR.message_types_by_name['KeyInfo'] = _KEYINFO
DESCRIPTOR.message_types_by_name['FabricOUIdentifier'] = _FABRICOUIDENTIFIER
DESCRIPTOR.message_types_by_name['FabricNodeOUs'] = _FABRICNODEOUS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MSPConfig = _reflection.GeneratedProtocolMessageType('MSPConfig', (_message.Message,), dict(
  DESCRIPTOR = _MSPCONFIG,
  __module__ = 'hfc.protos.msp.msp_config_pb2'
  # @@protoc_insertion_point(class_scope:msp.MSPConfig)
  ))
_sym_db.RegisterMessage(MSPConfig)

FabricMSPConfig = _reflection.GeneratedProtocolMessageType('FabricMSPConfig', (_message.Message,), dict(
  DESCRIPTOR = _FABRICMSPCONFIG,
  __module__ = 'hfc.protos.msp.msp_config_pb2'
  # @@protoc_insertion_point(class_scope:msp.FabricMSPConfig)
  ))
_sym_db.RegisterMessage(FabricMSPConfig)

FabricCryptoConfig = _reflection.GeneratedProtocolMessageType('FabricCryptoConfig', (_message.Message,), dict(
  DESCRIPTOR = _FABRICCRYPTOCONFIG,
  __module__ = 'hfc.protos.msp.msp_config_pb2'
  # @@protoc_insertion_point(class_scope:msp.FabricCryptoConfig)
  ))
_sym_db.RegisterMessage(FabricCryptoConfig)

IdemixMSPConfig = _reflection.GeneratedProtocolMessageType('IdemixMSPConfig', (_message.Message,), dict(
  DESCRIPTOR = _IDEMIXMSPCONFIG,
  __module__ = 'hfc.protos.msp.msp_config_pb2'
  # @@protoc_insertion_point(class_scope:msp.IdemixMSPConfig)
  ))
_sym_db.RegisterMessage(IdemixMSPConfig)

IdemixMSPSignerConfig = _reflection.GeneratedProtocolMessageType('IdemixMSPSignerConfig', (_message.Message,), dict(
  DESCRIPTOR = _IDEMIXMSPSIGNERCONFIG,
  __module__ = 'hfc.protos.msp.msp_config_pb2'
  # @@protoc_insertion_point(class_scope:msp.IdemixMSPSignerConfig)
  ))
_sym_db.RegisterMessage(IdemixMSPSignerConfig)

SigningIdentityInfo = _reflection.GeneratedProtocolMessageType('SigningIdentityInfo', (_message.Message,), dict(
  DESCRIPTOR = _SIGNINGIDENTITYINFO,
  __module__ = 'hfc.protos.msp.msp_config_pb2'
  # @@protoc_insertion_point(class_scope:msp.SigningIdentityInfo)
  ))
_sym_db.RegisterMessage(SigningIdentityInfo)

KeyInfo = _reflection.GeneratedProtocolMessageType('KeyInfo', (_message.Message,), dict(
  DESCRIPTOR = _KEYINFO,
  __module__ = 'hfc.protos.msp.msp_config_pb2'
  # @@protoc_insertion_point(class_scope:msp.KeyInfo)
  ))
_sym_db.RegisterMessage(KeyInfo)

FabricOUIdentifier = _reflection.GeneratedProtocolMessageType('FabricOUIdentifier', (_message.Message,), dict(
  DESCRIPTOR = _FABRICOUIDENTIFIER,
  __module__ = 'hfc.protos.msp.msp_config_pb2'
  # @@protoc_insertion_point(class_scope:msp.FabricOUIdentifier)
  ))
_sym_db.RegisterMessage(FabricOUIdentifier)

FabricNodeOUs = _reflection.GeneratedProtocolMessageType('FabricNodeOUs', (_message.Message,), dict(
  DESCRIPTOR = _FABRICNODEOUS,
  __module__ = 'hfc.protos.msp.msp_config_pb2'
  # @@protoc_insertion_point(class_scope:msp.FabricNodeOUs)
  ))
_sym_db.RegisterMessage(FabricNodeOUs)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: hfc/protos/common/collection.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from hfc.protos.common import policies_pb2 as hfc_dot_protos_dot_common_dot_policies__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='hfc/protos/common/collection.proto',
  package='common',
  syntax='proto3',
  serialized_options=_b('\n$org.hyperledger.fabric.protos.commonZ+github.com/hyperledger/fabric/protos/common'),
  serialized_pb=_b('\n\"hfc/protos/common/collection.proto\x12\x06\x63ommon\x1a hfc/protos/common/policies.proto\"C\n\x17\x43ollectionConfigPackage\x12(\n\x06\x63onfig\x18\x01 \x03(\x0b\x32\x18.common.CollectionConfig\"a\n\x10\x43ollectionConfig\x12\x42\n\x18static_collection_config\x18\x01 \x01(\x0b\x32\x1e.common.StaticCollectionConfigH\x00\x42\t\n\x07payload\"\xcc\x01\n\x16StaticCollectionConfig\x12\x0c\n\x04name\x18\x01 \x01(\t\x12:\n\x12member_orgs_policy\x18\x02 \x01(\x0b\x32\x1e.common.CollectionPolicyConfig\x12\x1b\n\x13required_peer_count\x18\x03 \x01(\x05\x12\x1a\n\x12maximum_peer_count\x18\x04 \x01(\x05\x12\x15\n\rblock_to_live\x18\x05 \x01(\x04\x12\x18\n\x10member_only_read\x18\x06 \x01(\x08\"`\n\x16\x43ollectionPolicyConfig\x12;\n\x10signature_policy\x18\x01 \x01(\x0b\x32\x1f.common.SignaturePolicyEnvelopeH\x00\x42\t\n\x07payload\"[\n\x12\x43ollectionCriteria\x12\x0f\n\x07\x63hannel\x18\x01 \x01(\t\x12\r\n\x05tx_id\x18\x02 \x01(\t\x12\x12\n\ncollection\x18\x03 \x01(\t\x12\x11\n\tnamespace\x18\x04 \x01(\tBS\n$org.hyperledger.fabric.protos.commonZ+github.com/hyperledger/fabric/protos/commonb\x06proto3')
  ,
  dependencies=[hfc_dot_protos_dot_common_dot_policies__pb2.DESCRIPTOR,])




_COLLECTIONCONFIGPACKAGE = _descriptor.Descriptor(
  name='CollectionConfigPackage',
  full_name='common.CollectionConfigPackage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='common.CollectionConfigPackage.config', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=80,
  serialized_end=147,
)


_COLLECTIONCONFIG = _descriptor.Descriptor(
  name='CollectionConfig',
  full_name='common.CollectionConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='static_collection_config', full_name='common.CollectionConfig.static_collection_config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='payload', full_name='common.CollectionConfig.payload',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=149,
  serialized_end=246,
)


_STATICCOLLECTIONCONFIG = _descriptor.Descriptor(
  name='StaticCollectionConfig',
  full_name='common.StaticCollectionConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='common.StaticCollectionConfig.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='member_orgs_policy', full_name='common.StaticCollectionConfig.member_orgs_policy', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='required_peer_count', full_name='common.StaticCollectionConfig.required_peer_count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='maximum_peer_count', full_name='common.StaticCollectionConfig.maximum_peer_count', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='block_to_live', full_name='common.StaticCollectionConfig.block_to_live', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='member_only_read', full_name='common.StaticCollectionConfig.member_only_read', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=249,
  serialized_end=453,
)


_COLLECTIONPOLICYCONFIG = _descriptor.Descriptor(
  name='CollectionPolicyConfig',
  full_name='common.CollectionPolicyConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='signature_policy', full_name='common.CollectionPolicyConfig.signature_policy', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='payload', full_name='common.CollectionPolicyConfig.payload',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=455,
  serialized_end=551,
)


_COLLECTIONCRITERIA = _descriptor.Descriptor(
  name='CollectionCriteria',
  full_name='common.CollectionCriteria',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='channel', full_name='common.CollectionCriteria.channel', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tx_id', full_name='common.CollectionCriteria.tx_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='collection', full_name='common.CollectionCriteria.collection', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='namespace', full_name='common.CollectionCriteria.namespace', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=553,
  serialized_end=644,
)

_COLLECTIONCONFIGPACKAGE.fields_by_name['config'].message_type = _COLLECTIONCONFIG
_COLLECTIONCONFIG.fields_by_name['static_collection_config'].message_type = _STATICCOLLECTIONCONFIG
_COLLECTIONCONFIG.oneofs_by_name['payload'].fields.append(
  _COLLECTIONCONFIG.fields_by_name['static_collection_config'])
_COLLECTIONCONFIG.fields_by_name['static_collection_config'].containing_oneof = _COLLECTIONCONFIG.oneofs_by_name['payload']
_STATICCOLLECTIONCONFIG.fields_by_name['member_orgs_policy'].message_type = _COLLECTIONPOLICYCONFIG
_COLLECTIONPOLICYCONFIG.fields_by_name['signature_policy'].message_type = hfc_dot_protos_dot_common_dot_policies__pb2._SIGNATUREPOLICYENVELOPE
_COLLECTIONPOLICYCONFIG.oneofs_by_name['payload'].fields.append(
  _COLLECTIONPOLICYCONFIG.fields_by_name['signature_policy'])
_COLLECTIONPOLICYCONFIG.fields_by_name['signature_policy'].containing_oneof = _COLLECTIONPOLICYCONFIG.oneofs_by_name['payload']
DESCRIPTOR.message_types_by_name['CollectionConfigPackage'] = _COLLECTIONCONFIGPACKAGE
DESCRIPTOR.message_types_by_name['CollectionConfig'] = _COLLECTIONCONFIG
DESCRIPTOR.message_types_by_name['StaticCollectionConfig'] = _STATICCOLLECTIONCONFIG
DESCRIPTOR.message_types_by_name['CollectionPolicyConfig'] = _COLLECTIONPOLICYCONFIG
DESCRIPTOR.message_types_by_name['CollectionCriteria'] = _COLLECTIONCRITERIA
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CollectionConfigPackage = _reflection.GeneratedProtocolMessageType('CollectionConfigPackage', (_message.Message,), dict(
  DESCRIPTOR = _COLLECTIONCONFIGPACKAGE,
  __module__ = 'hfc.protos.common.collection_pb2'
  # @@protoc_insertion_point(class_scope:common.CollectionConfigPackage)
  ))
_sym_db.RegisterMessage(CollectionConfigPackage)

CollectionConfig = _reflection.GeneratedProtocolMessageType('CollectionConfig', (_message.Message,), dict(
  DESCRIPTOR = _COLLECTIONCONFIG,
  __module__ = 'hfc.protos.common.collection_pb2'
  # @@protoc_insertion_point(class_scope:common.CollectionConfig)
  ))
_sym_db.RegisterMessage(CollectionConfig)

StaticCollectionConfig = _reflection.GeneratedProtocolMessageType('StaticCollectionConfig', (_message.Message,), dict(
  DESCRIPTOR = _STATICCOLLECTIONCONFIG,
  __module__ = 'hfc.protos.common.collection_pb2'
  # @@protoc_insertion_point(class_scope:common.StaticCollectionConfig)
  ))
_sym_db.RegisterMessage(StaticCollectionConfig)

CollectionPolicyConfig = _reflection.GeneratedProtocolMessageType('CollectionPolicyConfig', (_message.Message,), dict(
  DESCRIPTOR = _COLLECTIONPOLICYCONFIG,
  __module__ = 'hfc.protos.common.collection_pb2'
  # @@protoc_insertion_point(class_scope:common.CollectionPolicyConfig)
  ))
_sym_db.RegisterMessage(CollectionPolicyConfig)

CollectionCriteria = _reflection.GeneratedProtocolMessageType('CollectionCriteria', (_message.Message,), dict(
  DESCRIPTOR = _COLLECTIONCRITERIA,
  __module__ = 'hfc.protos.common.collection_pb2'
  # @@protoc_insertion_point(class_scope:common.CollectionCriteria)
  ))
_sym_db.RegisterMessage(CollectionCriteria)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
